import resolve from '@rollup/plugin-node-resolve';
import commonjs from '@rollup/plugin-commonjs';
import typescript from '@rollup/plugin-typescript';
import external from 'rollup-plugin-peer-deps-external';
import postcss from 'rollup-plugin-postcss';
import dts from 'rollup-plugin-dts';
import terser from '@rollup/plugin-terser';
import json from '@rollup/plugin-json'; // Import the json plugin

export default [
    {
        input: 'src/index.ts',
        output: [
            {
                file: 'dist/cjs/index.js', // Use direct path instead of packageJson.main
                format: 'cjs',
                sourcemap: true,
                name: 'invirtu-react-widgets'
            },
            {
                file: 'dist/esm/index.js', // Use direct path instead of packageJson.module
                format: 'esm',
                sourcemap: true
            }
        ],
        plugins: [
            external(),
            resolve(),
            commonjs(),
            typescript({ tsconfig: './tsconfig.json' }),
            postcss(),
            terser(),
            json() // Use the json plugin
        ],
    },
    {
        input: 'dist/esm/types/index.d.ts',
        output: [{ file: 'dist/index.d.ts', format: "esm" }],
        external: [
          /\.css$/, 
          'react',
          'react-dom'
      ],
        plugins: [dts()],
    },
];
